LmsToXyz

Trait LmsToXyz 

pub trait LmsToXyz<T> {
    // Required method
    fn lms_to_xyz_matrix() -> [T; 9];
}
Provides a matrix for converting from Lms to Xyz.

Required Methods

fn lms_to_xyz_matrix() -> [T; 9]

Get an Lms to Xyz conversion matrix with elements of type T.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> LmsToXyz<T> for Bradford
where T: Real,

Source

impl<T> LmsToXyz<T> for UnitMatrix
where T: Real,

Source

impl<T> LmsToXyz<T> for VonKries
where T: Real,