XyzToLms

Trait XyzToLms 

pub trait XyzToLms<T> {
    // Required method
    fn xyz_to_lms_matrix() -> [T; 9];
}
Provides a matrix for converting from Xyz to Lms.

Required Methods

fn xyz_to_lms_matrix() -> [T; 9]

Get an Xyz to Lms conversion matrix with elements of type T.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> XyzToLms<T> for Bradford
where T: Real,

Source

impl<T> XyzToLms<T> for UnitMatrix
where T: Real,

Source

impl<T> XyzToLms<T> for VonKries
where T: Real,